import logging
from argparse import ArgumentParser
from distutils.util import strtobool
from os import getenv

path = getenv("AUTOPYPA_PATH", "")
verbose = int(getenv("AUTOPYPA_VERBOSE", "0"))
secret = getenv("AUTOPYPA_SECRET", "")
debug = strtobool(getenv("AUTOPYPA_DEBUG", "n"))
addr = getenv("AUTOPYPA_ADDR", "127.0.0.1")
port = int(getenv("AUTOPYPA_PORT", "5000"))

def cli():
    parser = ArgumentParser(description=(
        "Automatic Python Packager used to package and distribute projects"))
    parser.add_argument("-v", "--verbose", dest="loglevel", action="count",
            default=verbose,
            help="increase verbosity")
    parser.add_argument("-s", "--secret", dest="secret", action="store",
            default=secret,
            help="webhook secret")
    parser.add_argument("--debug", dest="debug", action="store_const",
            default=debug, const=True,
            help="start builtin debug server")
    parser.add_argument("--addr", dest="addr", action="store",
            default=addr,
            help="IP address of the builtin debug server")
    parser.add_argument("--port", dest="port", action="store", type=int,
            default=port,
            help="TCP port of the builtin debug server")
    parser.add_argument(dest="path", action="store",
            help="package index path")
    options = parser.parse_args()
    logging.basicConfig(level=["WARNING", "INFO", "DEBUG"][min(2, options.loglevel or 0)])

    # make every option direcly accessible at module level
    globals().update(options.__dict__)
