from re import sub as re_sub
from os import mkdir
from os.path import isdir, join as pjoin
from logging import getLogger

from . import config
from .server import session

logger = getLogger(__name__)

def normalize(name):
    return re_sub(r"[-_.]+", "-", name).lower()

async def download(project_name, version, tarball_url):
    # path and filename according to PEP 503
    project_root = pjoin(config.path, normalize(project_name))
    if not isdir(project_root):
        logger.info("Creating new folder for project %s", project_name)
        mkdir(project_root)
    filepath = pjoin(project_root, "%s-%s.tar.gz" % (project_name, version))

    logger.info("Downloading %s...", tarball_url)
    async with session.get(tarball_url) as resp:
        if resp.status != 200:
            logger.error("Error while downloading the file, code: %d\n%s",
                resp.status, await resp.text())
            return
        with open(filepath, 'wb') as fd:
            while True:
                chunk = await resp.content.read(128)
                if not chunk:
                    break
                fd.write(chunk)
    logger.info("Download done, package is available at %s", filepath)
