from aiohttp import web
from logging import getLogger
from asyncio import ensure_future
try:
    from secrets import compare_digest
except ImportError:
    from operator import eq
    compare_digest = eq

from . import config
from .download import download


logger = getLogger(__name__)

async def hook(request):
    payload = await request.json()
    from pprint import pformat
    logger.debug(pformat(payload))

    if payload["action"] not in ["updated", "published"]:
        logger.warning("Please configure gitea to only trigger the "
                       "hook on \"Release\" events.")
        return web.Response()

    if config.secret and not compare_digest(payload.get("secret"), config.secret):
        logger.error("Invalid secret: %s", payload.get("secret", None))
        return web.Response("Invalid secret !", status=403)

    logger.info("New release on %s: %s",
        payload["repository"]["full_name"],
        payload["release"]["name"])
    ensure_future(download(
        payload["repository"]["name"],
        payload["release"]["tag_name"],
        payload["release"]["tarball_url"]))

    return web.Response()
